@@ -458,6 +458,14 @@ def test_yaml() -> None:
     _assert_required(soup, [False, True, True, True, False])
 
 
+def test_single_element_allOf() -> None:
+    """Test loading schema that has a single-element allOf property"""
+    soup = _generate_case("single_element_allOf")
+
+    _assert_title(soup, "Schema containing a single-element allOf")
+    _assert_descriptions(soup, ["Schema containing a single-element allOf", "My string definition"])
+
+
 def test_json_with_tabs() -> None:
     """Test loading the schema when tabs are present rather than spaces. Regression test for #45"""
     temp_schema_file = tempfile.NamedTemporaryFile(mode="w+", delete=False, suffix=".json")
